@@ -5,12 +5,12 @@ use Carp ();
 
 require Exporter;
 @ISA=qw(Exporter);
-@EXPORT_OK = qw(tekstdato helligdag helligdager @UKEDAGER @MANEDER);
+@EXPORT_OK = qw(tekstdato helligdag hverdag helligdager @UKEDAGER @MANEDER);
 
 use strict;
 use vars qw(%SPECIAL_DAYS @UKEDAGER @MANEDER $VERSION);
 
-$VERSION = sprintf("%d.%02d", q$Revision: 1.6 $ =~ /(\d+)\.(\d+)/);
+$VERSION = sprintf("%d.%02d", q$Revision: 1.10 $ =~ /(\d+)\.(\d+)/);
 
 
 =head1 NAME
@@ -36,8 +36,8 @@ No::Dato - Norwegian dates
 B<This documentation is written in Norwegian.>
 
 Denne modulen tilbyr funksjoner for  hndtere det som er spesielt med
-datoer p norsk.  Dette gjelder blandt annet  finne fram til de
-norske helligdagene.
+datoer p norsk.  Dette gjelder blant annet  identifisere offentlige
+hytidsdager.
 
 Flgende funksjoner er tilgjengelig:
 
@@ -49,23 +49,23 @@ Flgende funksjoner er tilgjengelig:
 
 
 %SPECIAL_DAYS = (
-  "Nyttrsdag"            => '01-01',
+  "nyttrsdag"            => '01-01',
   "1. mai"                => '05-01',
-  "Grunnlovsdag"          => '05-17',
-  "Juledag"               => '12-25',
-  "2. Juledag"            => '12-26',
+  "grunnlovsdag"          => '05-17',
+  "juledag"               => '12-25',
+  "2. juledag"            => '12-26',
 
   # relative to easter day
-  "Skjrtorsdag"          => -3,
-  "Langfredag"            => -2,
-  "Pskedag"              =>  0,
-  "2. Pskedag"           => +1,
-  "Kristi himmelfartsdag" => +39,
-  "Pinsedag"              => +49,
-  "2. Pinsedag"           => +50,
+  "skjrtorsdag"          => -3,
+  "langfredag"            => -2,
+  "pskedag"              =>  0,
+  "2. pskedag"           => +1,
+  "kristi himmelfartsdag" => +39,
+  "pinsedag"              => +49,
+  "2. pinsedag"           => +50,
 );
 
-@UKEDAGER = qw(Sndag Mandag Tirsdag Onsdag Torsdag Fredag Lrdag);
+@UKEDAGER = qw(sndag mandag tirsdag onsdag torsdag fredag lrdag);
 @MANEDER = qw(januar februar mars      april   mai      juni
               juli   august  september oktober november desember);
 
@@ -76,7 +76,7 @@ my %hellig_cache = ();
 
 Denne rutinen returnerer en dato formatert p formen:
 
-  Fredag, 7. februar 1997
+  fredag, 7. februar 2004
 
 Argumentet er en vanlig perl $time verdi.  Hvis argumentet utelates s
 benyttes dagens dato.
@@ -95,15 +95,20 @@ sub tekstdato (;$)
 
 Rutinen avgjr om en gitt dato er en norsk helligdag eller ikke.  Hvis
 det er en helligdag s vil navnet p helligdagen bli returnert.  Hvis
-det er en vanlig hverdag s vil en tom streng (som er FALSE i perl)
-bli returnert.
+det er en vanlig hverdag eller lrdag s vil en tom streng (som er
+FALSE i perl) bli returnert.
 
 Argumentet kan vre en vanlig $time verdi eller en streng p formen
 "-MM-DD".
 
+For denne funksjonen er "helligdag" definert til  vre det samme som
+norsk offentlig hytidsdag samt sndager, dvs de dagene som er rde p
+kalenderen.  Dette inkluderer nyttrsdagen, samt 1. og 17. mai selv om
+disse egentlig ikke er hellige.
+
 =cut
 
-sub helligdag (;$)
+sub helligdag (;$$)
 {
     my $date = shift || time;
     my $year;
@@ -128,11 +133,25 @@ sub helligdag (;$)
 	    my($m, $d) = split(/-/, $date);
 	    $weekday = (localtime(timelocal(12,0,0,$d, $m-1, $year-1900)))[6];
         }
-        $day = "Sndag" if $weekday == 0;
+        $day = "sndag" if $weekday == 0;
+	$day = "lrdag" if $weekday == 6 && $_[0];
     }
     $day;
 }
 
+=item hverdag($time)
+
+Rutinen avgjr om en gitt date er en hverdag eller ikke.  Lrdag er
+her ikke regnet som hverdag.
+
+Argumentet kan vre en vanlig $time verdi eller en streng p formen
+"-MM-DD".
+
+=cut
+
+sub hverdag {
+    return !helligdag(shift, 1);
+}
 
 =item helligdager($year)
 
@@ -140,11 +159,15 @@ Denne rutinen vil returnere en liste av datostrenger, n for hver
 helligdag i ret gitt som argument.  Hvis argumentet mangler vil vi
 bruke innevrende r.  Datostrengene er p formen:
 
-   "-MM-DD Skjrtorsdag"
+   "-MM-DD skjrtorsdag"
 
-Dvs. datoen formattert i henhold til ISO 8601 etterfulgt av navnet p
+Dvs. datoen formatert i henhold til ISO 8601 etterfulgt av navnet p
 helligdagen.  Listen vil vre sortert p dato.
 
+For denne funksjonen er "helligdag" definert til  vre det samme som
+norsk offentlig hytidsdag.  Sndagene er ikke tatt med selv om
+funksjonen helligdag(), beskrevet over, er TRUE for disse.
+
 =cut
 
 sub helligdager (;$)
@@ -163,12 +186,6 @@ sub helligdager (;$)
 	    } else {
 		($month, $mday) = dayno_to_date($year, $easter + $date);
 	    }
-	    # sjekk om det er en sndag i tillegg
-	    if ($year >= 1970 &&
-		(localtime(timelocal(12, 0, 0,
-				     $mday, $month-1, $year-1900)))[6] == 0) {
-		$text .= " (Sndag)";
-	    }
 	    $hellig_cache{$year}{sprintf "%02d-%02d", $month, $mday} = $text;
 	}
     }
